@@ -64,10 +64,13 @@ public:
 
     bool isValid() const;
 
-    QSGNode* updatePaintNode(QSGNode * oldNode, UpdatePaintNodeData * updatePaintNodeData);
+    void updatePolish() Q_DECL_OVERRIDE;
+    QSGNode* updatePaintNode(QSGNode * oldNode, UpdatePaintNodeData * updatePaintNodeData) Q_DECL_OVERRIDE;
 
     void geometryChanged(const QRectF &newGeometry,
-                         const QRectF &oldGeometry);
+                         const QRectF &oldGeometry) Q_DECL_OVERRIDE;
+
+    void componentComplete() Q_DECL_OVERRIDE;
 
 Q_SIGNALS:
     void activeChanged();
@@ -77,11 +80,13 @@ Q_SIGNALS:
     void colorGroupChanged();
 
 private Q_SLOTS:
-    void loadPixmap();
+    void schedulePixmapUpdate();
     void animationFinished();
     void valueChanged(const QVariant &value);
 
 private:
+    void loadPixmap();
+
     //all the ways we can set an source. Only one of them will be valid
     QIcon m_icon;
     Plasma::Svg *m_svgIcon;
@@ -89,7 +94,6 @@ private:
     QImage m_imageIcon;
     //this contains the raw variant it was passed
     QVariant m_source;
-    QTimer m_loadPixmapTimer;
 
     QSizeF m_implicitSize;
 
@@ -99,6 +103,8 @@ private:
     bool m_textureChanged;
     bool m_sizeChanged;
 
+    bool m_svgFromIconLoader;
+
     QPixmap m_iconPixmap;
     QPixmap m_oldIconPixmap;
 
@@ -107,6 +113,7 @@ private:
     //animation on pixmap change
     QPropertyAnimation *m_animation;
     qreal m_animValue;
+
 };
 
 #endif
