@@ -33,13 +33,11 @@ class QPropertyAnimation;
 
 namespace KDeclarative
 {
-    class QmlObject;
+class QmlObject;
 }
 
 /**
- * QML wrapper for kdelibs Plasma::ToolTipDialog
- *
- * Exposed as `ToolTipDialog` in QML.
+ * Internally used by Tooltip
  */
 class ToolTipDialog : public PlasmaQuick::Dialog
 {
@@ -57,7 +55,7 @@ public:
     /**
      * animate the position change if visible
      */
-    virtual void adjustGeometry(const QRect &geom);
+    void adjustGeometry(const QRect &geom) Q_DECL_OVERRIDE;
 
     void dismiss();
     void keepalive();
@@ -65,11 +63,20 @@ public:
     bool interactive();
     void setInteractive(bool interactive);
 
+    bool animationsEnabled() const;
+    void setAnimationsEnabled(bool enabled);
+
+    /**
+     * Basically the last one who has shown the dialog
+     */
+    QObject *owner() const;
+    void setOwner(QObject *owner);
+
 protected:
-    void showEvent(QShowEvent *event);
-    void hideEvent(QHideEvent *event);
-    void resizeEvent(QResizeEvent *re);
-    bool event(QEvent *e);
+    void showEvent(QShowEvent *event) Q_DECL_OVERRIDE;
+    void hideEvent(QHideEvent *event) Q_DECL_OVERRIDE;
+    void resizeEvent(QResizeEvent *re) Q_DECL_OVERRIDE;
+    bool event(QEvent *e) Q_DECL_OVERRIDE;
 
 private Q_SLOTS:
     void valueChanged(const QVariant &value);
@@ -79,8 +86,9 @@ private:
     QTimer *m_showTimer;
     QPropertyAnimation *m_animation;
     int m_hideTimeout;
-    Plasma::Types::Direction m_direction;
     bool m_interactive;
+    bool m_animationsEnabled;
+    QObject *m_owner;
 };
 
 #endif
