@@ -42,7 +42,6 @@
 #include <kplugininfo.h>
 #include <klocalizedstring.h>
 #include <kservice.h>
-#include <kservicetypetrader.h>
 #include <KConfigLoader>
 #include <kwindowsystem.h>
 
@@ -56,6 +55,7 @@
 #include "private/associatedapplicationmanager_p.h"
 #include "private/containment_p.h"
 #include "private/package_p.h"
+#include "debug_p.h"
 
 namespace Plasma
 {
@@ -64,7 +64,7 @@ Applet::Applet(const KPluginInfo &info, QObject *parent, uint appletId)
     :  QObject(parent),
        d(new AppletPrivate(KService::Ptr(), &info, appletId, this))
 {
-    qDebug() << " From KPluginInfo, valid? " << info.isValid();
+    qCDebug(LOG_PLASMA) << " From KPluginInfo, valid? " << info.isValid();
     // WARNING: do not access config() OR globalConfig() in this method!
     //          that requires a scene, which is not available at this point
     d->init();
@@ -84,10 +84,13 @@ Applet::Applet(QObject *parent, const QString &serviceID, uint appletId)
 Applet::Applet(QObject *parentObject, const QVariantList &args)
     :  QObject(0),
        d(new AppletPrivate(
-             KService::serviceByStorageId(args.count() > 0 ? args[0].toString() : QString()), 0,
+             KService::serviceByStorageId(args.count() > 0 && args.first().canConvert<QString>() ? args[0].toString() : QString()), 0,
              args.count() > 1 ? args[1].toInt() : 0, this))
 {
     setParent(parentObject);
+    if (args.count() > 0 && args.first().canConvert<QVariantMap>()) {
+        d->appletDescription = KPluginInfo(args);
+    }
 
     // WARNING: do not access config() OR globalConfig() in this method!
     //          that requires a scene, which is not available at this point
@@ -139,7 +142,7 @@ void Applet::save(KConfigGroup &g) const
         group = *d->mainConfigGroup();
     }
 
-    //qDebug() << "saving" << pluginName() << "to" << group.name();
+    //qCDebug(LOG_PLASMA) << "saving" << pluginName() << "to" << group.name();
     // we call the dptr member directly for locked since isImmutable()
     // also checks kiosk and parent containers
     group.writeEntry("immutability", (int)d->immutability);
@@ -172,10 +175,10 @@ void Applet::restore(KConfigGroup &group)
         setGlobalShortcut(QKeySequence(shortcutText));
         /*
         #ifndef NDEBUG
-        // qDebug() << "got global shortcut for" << name() << "of" << QKeySequence(shortcutText);
+        // qCDebug(LOG_PLASMA) << "got global shortcut for" << name() << "of" << QKeySequence(shortcutText);
         #endif
         #ifndef NDEBUG
-        // qDebug() << "set to" << d->activationAction->objectName()
+        // qCDebug(LOG_PLASMA) << "set to" << d->activationAction->objectName()
         #endif
                  << d->activationAction->globalShortcut().primary();
                  */
@@ -312,7 +315,7 @@ void Applet::constraintsEvent(Plasma::Types::Constraints constraints)
     //      without calling the Applet:: version as well, which it shouldn't need to.
     //      INSTEAD put such code into flushPendingConstraintsEvents
     Q_UNUSED(constraints)
-    //qDebug() << constraints << "constraints are FormFactor: " << formFactor()
+    //qCDebug(LOG_PLASMA) << constraints << "constraints are FormFactor: " << formFactor()
     //         << ", Location: " << location();
     if (d->script) {
         d->script->constraintsEvent(constraints);
@@ -450,6 +453,9 @@ Types::ItemStatus Applet::status() const
 
 void Applet::setStatus(const Types::ItemStatus status)
 {
+    if (status == d->itemStatus) {
+        return;
+    }
     d->itemStatus = status;
     emit statusChanged(status);
 }
@@ -464,7 +470,7 @@ void Applet::flushPendingConstraintsEvents()
         d->constraintsTimer.stop();
     }
 
-    //qDebug() << "fushing constraints: " << d->pendingConstraints << "!!!!!!!!!!!!!!!!!!!!!!!!!!!";
+    //qCDebug(LOG_PLASMA) << "fushing constraints: " << d->pendingConstraints << "!!!!!!!!!!!!!!!!!!!!!!!!!!!";
     Plasma::Types::Constraints c = d->pendingConstraints;
     d->pendingConstraints = Types::NoConstraint;
 
@@ -560,7 +566,7 @@ void Applet::flushPendingConstraintsEvents()
 
 QList<QAction *> Applet::contextualActions()
 {
-    //qDebug() << "empty context actions";
+    //qCDebug(LOG_PLASMA) << "empty context actions";
     return d->script ? d->script->contextualActions() : QList<QAction *>();
 }
 
@@ -612,7 +618,7 @@ void Applet::setGlobalShortcut(const QKeySequence &shortcut)
     if (!d->activationAction) {
         d->activationAction = new QAction(this);
         d->activationAction->setText(i18n("Activate %1 Widget", title()));
-        d->activationAction->setObjectName(QString("activate widget %1").arg(id())); // NO I18N
+        d->activationAction->setObjectName(QStringLiteral("activate widget %1").arg(id())); // NO I18N
         connect(d->activationAction, SIGNAL(triggered()), this, SIGNAL(activated()));
         connect(d->activationAction, SIGNAL(changed()),
                 this, SLOT(globalShortcutChanged()));
@@ -657,12 +663,12 @@ void Applet::setHasConfigurationInterface(bool hasInterface)
         return;
     }
 
-    QAction *configAction = d->actions->action("configure");
+    QAction *configAction = d->actions->action(QStringLiteral("configure"));
     if (configAction) {
         bool enable = hasInterface;
         if (enable) {
             const bool unlocked = immutability() == Types::Mutable;
-            enable = unlocked || KAuthorized::authorize("plasma/allow_configure_when_locked");
+            enable = unlocked || KAuthorized::authorize(QStringLiteral("plasma/allow_configure_when_locked"));
         }
         configAction->setEnabled(enable);
     }
@@ -726,11 +732,12 @@ bool Applet::hasValidAssociatedApplication() const
 
 Applet *Applet::loadPlasmoid(const QString &path, uint appletId)
 {
-    if (QFile::exists(path + "/metadata.desktop")) {
-        KService service(path + "/metadata.desktop");
+    const QString metadataPath = path + QLatin1String("/metadata.desktop");
+    if (QFile::exists(metadataPath)) {
+        KService service(metadataPath);
         const QStringList &types = service.serviceTypes();
 
-        if (types.contains("Plasma/Containment")) {
+        if (types.contains(QStringLiteral("Plasma/Containment"))) {
             return new Containment(path, appletId);
         } else {
             return new Applet(path, appletId);
