@@ -33,6 +33,8 @@
 #include <plasma/version.h>
 #include <plasma/framesvg.h>
 
+#include <KPackage/Package>
+
 class KActionCollection;
 class KConfigLoader;
 
@@ -65,6 +67,12 @@ class Package;
 class PLASMA_EXPORT Applet : public QObject
 {
     Q_OBJECT
+    Q_PROPERTY(Plasma::Types::ItemStatus status READ status WRITE setStatus NOTIFY statusChanged)
+    Q_PROPERTY(Plasma::Types::ImmutabilityType immutability READ immutability WRITE setImmutability NOTIFY immutabilityChanged)
+    Q_PROPERTY(Plasma::Types::FormFactor formFactor READ formFactor NOTIFY formFactorChanged)
+    Q_PROPERTY(Plasma::Types::Location location READ location NOTIFY locationChanged)
+    Q_PROPERTY(QString title READ title WRITE setTitle FINAL)
+    Q_PROPERTY(QString icon READ icon WRITE setIcon FINAL)
 
 public:
 //CONSTRUCTORS
@@ -218,13 +226,26 @@ public:
     void setUserConfiguring(bool configuring);
 
 //UTILS
+#ifndef PLASMA_NO_DEPRECATED
+    /**
+     * Accessor for the associated Package object if any.
+     * Generally, only Plasmoids come in a Package.
+     * Deprecated: please use kPackage()
+     *
+     * @deprecated use kPackage() instead
+     * @return the Package object, or an invalid one if none
+     **/
+    PLASMA_DEPRECATED Package package() const;
+#endif
+
     /**
      * Accessor for the associated Package object if any.
      * Generally, only Plasmoids come in a Package.
      *
      * @return the Package object, or an invalid one if none
+     * @since 5.6
      **/
-    Package package() const;
+    KPackage::Package kPackage() const;
 
     /**
      * Called when any of the geometry constraints have been updated.
@@ -377,6 +398,13 @@ Q_SIGNALS:
      */
     void statusChanged(Plasma::Types::ItemStatus status);
 
+    /**
+     * Emitted when the applet has been scheduled for destruction
+     * or the destruction has been undone
+     * @since 5.4
+     */
+    void destroyedChanged(bool destroyed);
+
 //CONFIGURATION
     /**
      * Emitted when an applet has changed values in its configuration
@@ -564,7 +592,7 @@ protected:
     /**
      * Reimplemented from QObject
      */
-    void timerEvent(QTimerEvent *event);
+    void timerEvent(QTimerEvent *event) Q_DECL_OVERRIDE;
 
 private:
     /**
@@ -608,4 +636,8 @@ private:
     K_PLUGIN_FACTORY(factory, registerPlugin<classname>();) \
     K_EXPORT_PLUGIN_VERSION(PLASMA_VERSION)
 
+#define K_EXPORT_PLASMA_APPLET_WITH_JSON(libname, classname, jsonFile) \
+    K_PLUGIN_FACTORY_WITH_JSON(factory, jsonFile, registerPlugin<classname>();) \
+    K_EXPORT_PLUGIN_VERSION(PLASMA_VERSION)
+
 #endif // multiple inclusion guard
