@@ -46,6 +46,7 @@
 #include "private/containment_p.h"
 #include "private/package_p.h"
 #include "timetracker.h"
+#include "debug_p.h"
 
 namespace Plasma
 {
@@ -80,17 +81,19 @@ AppletPrivate::AppletPrivate(KService::Ptr service, const KPluginInfo *info, int
     } else if (appletId > s_maxAppletId) {
         s_maxAppletId = appletId;
     }
-    QObject::connect(actions->action("configure"), SIGNAL(triggered()),
+    QObject::connect(actions->action(QStringLiteral("configure")), SIGNAL(triggered()),
                      q, SLOT(requestConfiguration()));
 #ifndef NDEBUG
-    new TimeTracker(q);
+    if (qEnvironmentVariableIsSet("PLASMA_TRACK_STARTUP")) {
+        new TimeTracker(q);
+    }
 #endif
 }
 
 AppletPrivate::~AppletPrivate()
 {
     if (activationAction && globalShortcutEnabled) {
-        //qDebug() << "resetting global action for" << q->title() << activationAction->objectName();
+        //qCDebug(LOG_PLASMA) << "resetting global action for" << q->title() << activationAction->objectName();
         KGlobalAccel::self()->removeAllShortcuts(activationAction);
     }
 
@@ -115,7 +118,7 @@ void AppletPrivate::init(const QString &packagePath, const QVariantList &args)
     //          that requires a Corona, which is not available at this point
     q->setHasConfigurationInterface(true);
 
-    QAction *closeApplet = actions->action("remove");
+    QAction *closeApplet = actions->action(QStringLiteral("remove"));
     if (closeApplet) {
         closeApplet->setText(i18nc("%1 is the name of the applet", "Remove this %1", q->title()));
     }
@@ -127,7 +130,7 @@ void AppletPrivate::init(const QString &packagePath, const QVariantList &args)
 
     if (!appletDescription.isValid()) {
 #ifndef NDEBUG
-        // qDebug() << "Check your constructor! "
+        // qCDebug(LOG_PLASMA) << "Check your constructor! "
         //         << "You probably want to be passing in a Service::Ptr "
         //         << "or a QVariantList with a valid storageid as arg[0].";
 #endif
@@ -167,7 +170,7 @@ void AppletPrivate::init(const QString &packagePath, const QVariantList &args)
     //It's valid, let's try to load the icon from within the package
     if (script) {
         //use the absolute path of the in-package icon as icon name
-        if (appletDescription.icon().startsWith("/")) {
+        if (appletDescription.icon().startsWith('/')) {
             icon = package->filePath("", appletDescription.icon().toUtf8());
         }
     //package not valid, get rid of it
@@ -182,12 +185,12 @@ void AppletPrivate::init(const QString &packagePath, const QVariantList &args)
 
     if (!q->isContainment() && q->pluginInfo().isValid()) {
         QString constraint;
-        QStringList provides = q->pluginInfo().property("X-Plasma-Provides").value<QStringList>();
+        QStringList provides = q->pluginInfo().property("X-Plasma-Provides").toStringList();
         if (!provides.isEmpty()) {
             auto filter = [&provides](const KPluginMetaData &md) -> bool
             {
                 foreach (const QString &p, provides) {
-                    if (md.value("X-Plasma-Provides").contains(p)) {
+                    if (md.value(QStringLiteral("X-Plasma-Provides")).contains(p)) {
                         return true;
                     }
                 }
@@ -251,6 +254,7 @@ void AppletPrivate::askDestroy()
         //no parent, but it won't leak, since it will be closed both in case of timeout
         //or direct action
         deleteNotification = new KNotification("plasmoidDeleted", KNotification::Persistent, 0);
+        deleteNotification->setFlags(KNotification::SkipGrouping);
 
         deleteNotification->setComponentName("plasma_workspace");
         QStringList actions;
@@ -348,7 +352,7 @@ void AppletPrivate::globalShortcutChanged()
         shortcutConfig.writeEntry("global", newShortCut);
         scheduleModificationNotification();
     }
-    //qDebug() << "after" << shortcut.primary() << d->activationAction->globalShortcut().primary();
+    //qCDebug(LOG_PLASMA) << "after" << shortcut.primary() << d->activationAction->globalShortcut().primary();
 }
 
 KActionCollection *AppletPrivate::defaultActions(QObject *parent)
@@ -445,7 +449,7 @@ void AppletPrivate::setupPackage()
     }
 
 #ifndef NDEBUG
-    // qDebug() << "setting up script support, package is in" << package->path()
+    // qCDebug(LOG_PLASMA) << "setting up script support, package is in" << package->path()
     //         << ", main script is" << package->filePath("mainscript");
 #endif
 
@@ -511,7 +515,7 @@ KConfigGroup *AppletPrivate::mainConfigGroup()
     if (q->isContainment()) {
         Corona *corona = static_cast<Containment *>(q)->corona();
         KConfigGroup containmentConfig;
-        //qDebug() << "got a corona, baby?" << (QObject*)corona << (QObject*)q;
+        //qCDebug(LOG_PLASMA) << "got a corona, baby?" << (QObject*)corona << (QObject*)q;
 
         if (parentApplet) {
             containmentConfig = parentApplet->config();
@@ -531,7 +535,7 @@ KConfigGroup *AppletPrivate::mainConfigGroup()
             appletConfig = c->config();
             appletConfig = KConfigGroup(&appletConfig, "Applets");
         } else {
-            qWarning() << "requesting config for" << q->title() << "without a containment!";
+            qCWarning(LOG_PLASMA) << "requesting config for" << q->title() << "without a containment!";
             appletConfig = KConfigGroup(KSharedConfig::openConfig(), "Applets");
         }
 
