@@ -35,6 +35,7 @@
 
 #include "private/applet_p.h"
 #include "timetracker.h"
+#include "debug_p.h"
 
 namespace Plasma
 {
@@ -56,10 +57,6 @@ ContainmentPrivate::ContainmentPrivate(Containment *c):
     if (appletParent) {
         QObject::connect(appletParent->containment(), &Containment::screenChanged, c, &Containment::screenChanged);
     }
-
-#ifndef NDEBUG
-    new TimeTracker(q);
-#endif
 }
 
 Plasma::ContainmentPrivate::~ContainmentPrivate()
@@ -75,29 +72,29 @@ Plasma::ContainmentPrivate::~ContainmentPrivate()
 
 void ContainmentPrivate::addDefaultActions(KActionCollection *actions, Containment *c)
 {
-    actions->setConfigGroup("Shortcuts-Containment");
+    actions->setConfigGroup(QLatin1String("Shortcuts-Containment"));
 
     //adjust applet actions
-    QAction *appAction = qobject_cast<QAction *>(actions->action("remove"));
-    appAction->setShortcut(QKeySequence("alt+d, alt+r"));
+    QAction *appAction = qobject_cast<QAction *>(actions->action(QStringLiteral("remove")));
+    appAction->setShortcut(QKeySequence(Qt::ALT+Qt::Key_D, Qt::ALT+Qt::Key_R));
     if (c && c->d->isPanelContainment()) {
         appAction->setText(i18n("Remove this Panel"));
     } else {
         appAction->setText(i18n("Remove this Activity"));
     }
 
-    appAction = qobject_cast<QAction *>(actions->action("configure"));
+    appAction = qobject_cast<QAction *>(actions->action(QStringLiteral("configure")));
     if (appAction) {
-        appAction->setShortcut(QKeySequence("alt+d, alt+s"));
+        appAction->setShortcut(QKeySequence(Qt::ALT+Qt::Key_D, Qt::ALT+Qt::Key_S));
         appAction->setText(i18n("Activity Settings"));
     }
 
     //add our own actions
-    QAction *appletBrowserAction = actions->add<QAction>("add widgets");
+    QAction *appletBrowserAction = actions->add<QAction>(QLatin1String("add widgets"));
     appletBrowserAction->setAutoRepeat(false);
     appletBrowserAction->setText(i18n("Add Widgets..."));
-    appletBrowserAction->setIcon(QIcon::fromTheme("list-add"));
-    appletBrowserAction->setShortcut(QKeySequence("alt+d, a"));
+    appletBrowserAction->setIcon(QIcon::fromTheme(QLatin1String("list-add")));
+    appletBrowserAction->setShortcut(QKeySequence(Qt::ALT+Qt::Key_D, Qt::Key_A));
     appletBrowserAction->setData(Plasma::Types::AddAction);
 }
 
@@ -115,7 +112,7 @@ void ContainmentPrivate::configChanged()
 
 void ContainmentPrivate::checkStatus(Plasma::Types::ItemStatus appletStatus)
 {
-    //qDebug() << "================== "<< appletStatus << q->status();
+    //qCDebug(LOG_PLASMA) << "================== "<< appletStatus << q->status();
     if (appletStatus == q->status()) {
         emit q->statusChanged(appletStatus);
         return;
@@ -145,7 +142,7 @@ void ContainmentPrivate::containmentConstraintsEvent(Plasma::Types::Constraints
         return;
     }
 
-    //qDebug() << "got containmentConstraintsEvent" << constraints;
+    //qCDebug(LOG_PLASMA) << "got containmentConstraintsEvent" << constraints;
     if (constraints & Plasma::Types::ImmutableConstraint) {
         //update actions
         const bool unlocked = q->immutability() == Types::Mutable;
@@ -200,7 +197,7 @@ Applet *ContainmentPrivate::createApplet(const QString &name, const QVariantList
 
     if (q->immutability() != Types::Mutable) {
 #ifndef NDEBUG
-        // qDebug() << "addApplet for" << name << "requested, but we're currently immutable!";
+        // qCDebug(LOG_PLASMA) << "addApplet for" << name << "requested, but we're currently immutable!";
 #endif
         return 0;
     }
@@ -208,7 +205,7 @@ Applet *ContainmentPrivate::createApplet(const QString &name, const QVariantList
     Applet *applet = PluginLoader::self()->loadApplet(name, id, args);
 
     if (!applet) {
-        qWarning() << "Applet" << name << "could not be loaded.";
+        qCWarning(LOG_PLASMA) << "Applet" << name << "could not be loaded.";
         applet = new Applet(0, QString(), id);
         applet->setLaunchErrorMessage(i18n("Could not find requested component: %1", name));
     }
@@ -246,7 +243,7 @@ void ContainmentPrivate::setUiReady()
     //if we are the containment and there is still some uncomplete applet, we're still incomplete
     if (!uiReady) {
         uiReady = true;
-        if (q->Applet::d->started && appletsUiReady && loadingApplets.isEmpty()) {
+        if (q->Applet::d->started && (appletsUiReady || applets.isEmpty()) && loadingApplets.isEmpty()) {
             emit q->uiReadyChanged(true);
         }
     }
