@@ -34,19 +34,21 @@ class EffectWatcher: public QObject, public QAbstractNativeEventFilter
     Q_OBJECT
 
 public:
-    EffectWatcher(const QString& property, QObject *parent = 0);
+    EffectWatcher(const QString &property, QObject *parent = 0);
 
 protected:
     bool isEffectActive() const;
 
-    bool nativeEventFilter(const QByteArray& eventType, void *message, long *result) Q_DECL_OVERRIDE;
+    bool nativeEventFilter(const QByteArray &eventType, void *message, long *result) Q_DECL_OVERRIDE;
 
 Q_SIGNALS:
     void effectChanged(bool on);
 
 private:
+    void init(const QString &property);
     xcb_atom_t m_property;
     bool m_effectActive;
+    bool m_isX11;
 };
 
 } // namespace Plasma
