@@ -24,6 +24,7 @@
 #include <QSharedData>
 #include <QSvgRenderer>
 #include <QExplicitlySharedDataPointer>
+#include <QObject>
 
 namespace Plasma
 {
@@ -72,7 +73,7 @@ public:
     Theme *actualTheme();
     Theme *cacheAndColorsTheme();
 
-    QPixmap findInCache(const QString &elementId, const QSizeF &s = QSizeF());
+    QPixmap findInCache(const QString &elementId, qreal ratio, const QSizeF &s = QSizeF());
 
     void createRenderer();
     void eraseRenderer();
@@ -106,10 +107,14 @@ public:
     QSizeF size;
     QSizeF naturalSize;
     QChar styleCrc;
+    Theme::ColorGroup colorGroup;
     unsigned int lastModified;
     qreal devicePixelRatio;
+    qreal scaleFactor;
     bool multipleImages : 1;
     bool themed : 1;
+    bool useSystemColors : 1;
+    bool fromCurrentTheme : 1;
     bool applyColors : 1;
     bool usesColors : 1;
     bool cacheRendering : 1;
