@@ -84,7 +84,6 @@ public:
 public Q_SLOTS:
     void compositingChanged(bool active);
     void colorsChanged();
-    void blurBehindChanged(bool blur);
     void settingsFileChanged(const QString &settings);
     void scheduledCacheUpdate();
     void onAppExitCleanup();
@@ -96,13 +95,14 @@ Q_SIGNALS:
     void themeChanged();
     void defaultFontChanged();
     void smallestFontChanged();
+    void applicationPaletteChange();
 
 public:
     static const char defaultTheme[];
     static const char systemColorsTheme[];
     static const char themeRcFile[];
 #if HAVE_X11
-    static EffectWatcher *s_blurEffectWatcher;
+    static EffectWatcher *s_backgroundContrastEffectWatcher;
 #endif
 //Ref counting of ThemePrivate instances
     static ThemePrivate *globalTheme;
@@ -117,7 +117,7 @@ public:
     KColorScheme colorScheme;
     KColorScheme buttonColorScheme;
     KColorScheme viewColorScheme;
-    bool eventFilter(QObject *watched, QEvent *event);
+    bool eventFilter(QObject *watched, QEvent *event) Q_DECL_OVERRIDE;
     KConfigGroup cfg;
     QString defaultWallpaperTheme;
     QString defaultWallpaperSuffix;
@@ -142,7 +142,7 @@ public:
 
     bool locolor : 1;
     bool compositingActive : 1;
-    bool blurActive : 1;
+    bool backgroundContrastActive : 1;
     bool isDefault : 1;
     bool useGlobal : 1;
     bool hasWallpapers : 1;
@@ -153,6 +153,11 @@ public:
     qreal backgroundIntensity;
     qreal backgroundSaturation;
     bool backgroundContrastEnabled;
+
+    //Version number of Plasma the Theme has been designed for
+    int apiMajor;
+    int apiMinor;
+    int apiRevision;
 };
 
 }
