@@ -65,40 +65,26 @@ class PLASMA_EXPORT Theme : public QObject
     // stylesheet
     Q_PROPERTY(QString styleSheet READ styleSheet NOTIFY themeChanged)
 
-    // colors
-    Q_PROPERTY(QColor textColor READ textColor NOTIFY themeChanged)
-    Q_PROPERTY(QColor highlightColor READ highlightColor NOTIFY themeChanged)
-    Q_PROPERTY(QColor backgroundColor READ backgroundColor NOTIFY themeChanged)
-    Q_PROPERTY(QColor buttonTextColor READ buttonTextColor NOTIFY themeChanged)
-    Q_PROPERTY(QColor buttonBackgroundColor READ buttonBackgroundColor NOTIFY themeChanged)
-    Q_PROPERTY(QColor linkColor READ linkColor NOTIFY themeChanged)
-    Q_PROPERTY(QColor visitedLinkColor READ visitedLinkColor NOTIFY themeChanged)
-    Q_PROPERTY(QColor visitedLinkColor READ visitedLinkColor NOTIFY themeChanged)
-    Q_PROPERTY(QColor buttonHoverColor READ buttonHoverColor NOTIFY themeChanged)
-    Q_PROPERTY(QColor buttonFocusColor READ buttonFocusColor NOTIFY themeChanged)
-    Q_PROPERTY(QColor viewTextColor READ viewTextColor NOTIFY themeChanged)
-    Q_PROPERTY(QColor viewBackgroundColor READ viewBackgroundColor NOTIFY themeChanged)
-    Q_PROPERTY(QColor viewHoverColor READ viewHoverColor NOTIFY themeChanged)
-    Q_PROPERTY(QColor viewFocusColor READ viewFocusColor NOTIFY themeChanged)
-
 public:
     enum ColorRole {
         TextColor = 0, /**<  the text color to be used by items resting on the background */
-        HighlightColor = 1, /**<  the text highlight color to be used by items resting
+        BackgroundColor = 1, /**< the default background color */
+        HighlightColor = 2, /**<  the text highlight color to be used by items resting
                                    on the background */
-        BackgroundColor = 2, /**< the default background color */
-        ButtonTextColor = 4, /** text color for buttons */
-        ButtonBackgroundColor = 8, /** background color for buttons*/
-        LinkColor = 16, /** color for clickable links */
-        VisitedLinkColor = 32, /** color visited clickable links */
-        ButtonHoverColor = 64, /** color for hover effect on buttons */
-        ButtonFocusColor = 128, /** color for focus effect on buttons */
-        ViewTextColor = 256, /** text color for views */
-        ViewBackgroundColor = 512, /** background color for views */
-        ViewHoverColor = 1024, /** color for hover effect on view */
-        ViewFocusColor = 2048 /** color for focus effect on view */
+        HoverColor = 3, /** color for hover effect on view */
+        FocusColor = 4, /** color for focus effect on view */
+        LinkColor = 5, /** color for clickable links */
+        VisitedLinkColor = 6, /** color visited clickable links */
     };
 
+    enum ColorGroup {
+        NormalColorGroup = 0,
+        ButtonColorGroup = 1,
+        ViewColorGroup = 2,
+        ComplementaryColorGroup = 3
+    };
+    Q_ENUMS(ColorGroup)
+
     /**
      * Default constructor. It will be the global theme configured in plasmarc
      * @param parent the parent object
@@ -165,8 +151,9 @@ public:
      * Returns the text color to be used by items resting on the background
      *
      * @param role which role (usage pattern) to get the color for
+     * @param group which group we want a color of
      */
-    QColor color(ColorRole role) const;
+    QColor color(ColorRole role, ColorGroup group = NormalColorGroup) const;
 
     /**
      * Tells the theme whether to follow the global settings or use application
@@ -341,84 +328,6 @@ public:
      */
     QFont smallestFont() const;
 
-    /**
-     * @return The theme's colorscheme's text color
-     * @since 5.0
-     */
-    QColor textColor() const;
-
-    /**
-     * @return The theme's colorscheme's highlight color
-     * @since 5.0
-     */
-    QColor highlightColor() const;
-
-    /**
-     * @return The theme's colorscheme's background color
-     * @since 5.0
-     */
-    QColor backgroundColor() const;
-
-    /**
-     * @return The theme's colorscheme's color for text on buttons
-     * @since 5.0
-     */
-    QColor buttonTextColor() const;
-
-    /**
-     * @return The theme's colorscheme's background color color of buttons
-     * @since 5.0
-     */
-    QColor buttonBackgroundColor() const;
-
-    /**
-     * @return The theme's colorscheme's link color
-     * @since 5.0
-     */
-    QColor linkColor() const;
-
-    /**
-     * @return The theme's colorscheme's text color for visited links
-     * @since 5.0
-     */
-    QColor visitedLinkColor() const;
-
-    /**
-     * @return The theme's colorscheme's color of hovered buttons
-     * @since 5.0
-     */
-    QColor buttonHoverColor() const;
-
-    /**
-     * @return The theme's colorscheme's color of focused buttons
-     * @since 5.0
-     */
-    QColor buttonFocusColor() const;
-
-    /**
-     * @return The theme's colorscheme's text color in views
-     * @since 5.0
-     */
-    QColor viewTextColor() const;
-
-    /**
-     * @return The theme's colorscheme's background color of views
-     * @since 5.0
-     */
-    QColor viewBackgroundColor() const;
-
-    /**
-     * @return The theme's colorscheme's color of hovered views
-     * @since 5.0
-     */
-    QColor viewHoverColor() const;
-
-    /**
-     * @return The theme's colorscheme's color of focused views
-     * @since 5.0
-     */
-    QColor viewFocusColor() const;
-
     /** This method allows Plasma to enable and disable the background
      * contrast effect for a given theme, improving readability. The
      * value is read from the "enabled" key in the "ContrastEffect"
