@@ -33,8 +33,7 @@
 #include <Plasma/Applet>
 #include <Plasma/Containment>
 #include <Plasma/Corona>
-#include <kdeclarative/qmlobject.h>
-#include <plasma/scripting/appletscript.h>
+#include <kdeclarative/qmlobjectsharedengine.h>
 
 #include <packageurlinterceptor.h>
 
@@ -43,6 +42,10 @@ namespace PlasmaQuick
 
 QHash<QObject *, AppletQuickItem *> AppletQuickItemPrivate::s_rootObjects = QHash<QObject *, AppletQuickItem *>();
 
+//TODO: temporary
+QSet<QString> AppletQuickItemPrivate::s_legacyApplets = QSet<QString>({QStringLiteral("org.kde.plasma.bluetooth"), QStringLiteral("org.kde.plasma.pager"), QStringLiteral("org.kde.desktopcontainment"), QStringLiteral("org.kde.plasma.folder"), QStringLiteral("org.kde.panel"), QStringLiteral("org.kde.plasma.analogclock"), QStringLiteral("org.kde.plasma.battery"), QStringLiteral("org.kde.plasma.notifications"), QStringLiteral("org.kde.plasma.systemtray")});
+
+
 AppletQuickItemPrivate::AppletQuickItemPrivate(Plasma::Applet *a, AppletQuickItem *item)
     : q(item),
       switchWidth(-1),
@@ -50,6 +53,28 @@ AppletQuickItemPrivate::AppletQuickItemPrivate(Plasma::Applet *a, AppletQuickIte
       applet(a),
       expanded(false)
 {
+    if (!a->pluginInfo().isValid()) {
+        // This `qmlObject` is used in other parts of the code
+        qmlObject = new KDeclarative::QmlObject(q);
+        return;
+    }
+
+    //TODO: remove the legacy support at some point
+    //use the shared engine only for applets that are nt in the legacy list
+    //if they are, use the shared engine if their mayor version is at least 3
+    const QStringList version = a->pluginInfo().version().split(".");
+    if (!AppletQuickItemPrivate::s_legacyApplets.contains(a->pluginInfo().pluginName()) ||
+         (!version.isEmpty() && version.first().toInt() >= 3)) {
+
+        qmlObject = new KDeclarative::QmlObjectSharedEngine(q);
+        if (!qmlObject->engine()->urlInterceptor()) {
+            PackageUrlInterceptor *interceptor = new PackageUrlInterceptor(qmlObject->engine(), Plasma::Package());
+            qmlObject->engine()->setUrlInterceptor(interceptor);
+        }
+    } else {
+        qWarning() << "Falling back to legacy separed QQmlEngine for applet" << a->pluginInfo().pluginName();
+        qmlObject = new KDeclarative::QmlObject(q);
+    }
 }
 
 void AppletQuickItemPrivate::connectLayoutAttached(QObject *item)
@@ -89,8 +114,6 @@ void AppletQuickItemPrivate::connectLayoutAttached(QObject *item)
     propagateSizeHint("fillWidth");
     propagateSizeHint("fillHeight");
 
-    //HACK: check the Layout properties we wrote
-    QQmlProperty p(q, "Layout.minimumWidth", QtQml::qmlContext(qmlObject->rootObject()));
 
     QObject *ownLayout = 0;
 
@@ -170,7 +193,10 @@ QQuickItem *AppletQuickItemPrivate::createCompactRepresentationItem()
         return compactRepresentationItem;
     }
 
-    compactRepresentationItem = qobject_cast<QQuickItem*>(qmlObject->createObjectFromComponent(compactRepresentation, QtQml::qmlContext(qmlObject->rootObject())));
+    QVariantHash initialProperties;
+    initialProperties[QStringLiteral("parent")] = QVariant::fromValue(q);
+
+    compactRepresentationItem = qobject_cast<QQuickItem*>(qmlObject->createObjectFromComponent(compactRepresentation, QtQml::qmlContext(qmlObject->rootObject()), initialProperties));
 
     emit q->compactRepresentationItemChanged(compactRepresentationItem);
 
@@ -184,7 +210,9 @@ QQuickItem *AppletQuickItemPrivate::createFullRepresentationItem()
     }
 
     if (fullRepresentation && fullRepresentation != qmlObject->mainComponent()) {
-        fullRepresentationItem = qobject_cast<QQuickItem*>(qmlObject->createObjectFromComponent(fullRepresentation, QtQml::qmlContext(qmlObject->rootObject())));
+        QVariantHash initialProperties;
+        initialProperties[QStringLiteral("parent")] = QVariant::fromValue(q);
+        fullRepresentationItem = qobject_cast<QQuickItem*>(qmlObject->createObjectFromComponent(fullRepresentation, QtQml::qmlContext(qmlObject->rootObject()), initialProperties));
     } else {
         fullRepresentation = qmlObject->mainComponent();
         fullRepresentationItem = qobject_cast<QQuickItem*>(qmlObject->rootObject());
@@ -223,7 +251,7 @@ QQuickItem *AppletQuickItemPrivate::createCompactRepresentationExpanderItem()
 
 void AppletQuickItemPrivate::compactRepresentationCheck()
 {
-    if (!qmlObject->mainComponent() || qmlObject->mainComponent()->status() != QQmlComponent::Ready) {
+    if (!qmlObject->rootObject()) {
         return;
     }
 
@@ -273,8 +301,8 @@ void AppletQuickItemPrivate::compactRepresentationCheck()
             item->setParentItem(q);
             {
                 //set anchors
-                QQmlExpression expr(QtQml::qmlContext(qmlObject->rootObject()), item, "parent");
-                QQmlProperty prop(item, "anchors.fill");
+                QQmlExpression expr(QtQml::qmlContext(qmlObject->rootObject()), item, QStringLiteral("parent"));
+                QQmlProperty prop(item, QStringLiteral("anchors.fill"));
                 prop.write(expr.evaluate());
             }
 
@@ -300,8 +328,8 @@ void AppletQuickItemPrivate::compactRepresentationCheck()
             compactExpanderItem->setVisible(true);
             {
                 //set anchors
-                QQmlExpression expr(QtQml::qmlContext(qmlObject->rootObject()), compactExpanderItem, "parent");
-                QQmlProperty prop(compactExpanderItem, "anchors.fill");
+                QQmlExpression expr(QtQml::qmlContext(qmlObject->rootObject()), compactExpanderItem, QStringLiteral("parent"));
+                QQmlProperty prop(compactExpanderItem, QStringLiteral("anchors.fill"));
                 prop.write(expr.evaluate());
             }
 
@@ -375,14 +403,18 @@ AppletQuickItem::AppletQuickItem(Plasma::Applet *applet, QQuickItem *parent)
     if (d->applet && d->applet->containment() && d->applet->containment()->corona()) {
         d->coronaPackage = d->applet->containment()->corona()->package();
     }
+    if (d->applet && d->applet->containment()) {
+        d->containmentPackage = d->applet->containment()->package();
+    }
 
-    d->compactRepresentationCheckTimer.setSingleShot(true);
-    d->compactRepresentationCheckTimer.setInterval(250);
-    connect(&d->compactRepresentationCheckTimer, SIGNAL(timeout()),
-            this, SLOT(compactRepresentationCheck()));
-
-    d->qmlObject = new KDeclarative::QmlObject(this);
-    d->qmlObject->setTranslationDomain("plasma_applet_" + applet->pluginInfo().pluginName());
+    if (applet->pluginInfo().isValid()) {
+        const QString rootPath = applet->pluginInfo().property(QStringLiteral("X-Plasma-RootPath")).toString();
+        if (!rootPath.isEmpty()) {
+            d->qmlObject->setTranslationDomain(QLatin1String("plasma_applet_") + rootPath);
+        } else {
+            d->qmlObject->setTranslationDomain(QLatin1String("plasma_applet_") + applet->pluginInfo().pluginName());
+        }
+    }
     d->qmlObject->setInitializationDelayed(true);
 
     // set the graphicObject dynamic property on applet
@@ -397,15 +429,32 @@ AppletQuickItem::~AppletQuickItem()
     delete d->fullRepresentationItem;
     delete d->compactRepresentationExpanderItem;
 
-    AppletQuickItemPrivate::s_rootObjects.remove(d->qmlObject->engine());
+    AppletQuickItemPrivate::s_rootObjects.remove(d->qmlObject->rootContext());
 }
 
 AppletQuickItem *AppletQuickItem::qmlAttachedProperties(QObject *object)
 {
+    QQmlContext *context;
+    //is it using shared engine mode?
+    if (!QtQml::qmlEngine(object)->parent()) {
+        context = QtQml::qmlContext(object);
+        //search the root context of the applet in which the object is in
+        while (context) {
+            //the rootcontext of an applet is a child of the engine root context
+            if (context->parentContext() == QtQml::qmlEngine(object)->rootContext()) {
+                break;
+            }
+
+            context = context->parentContext();
+        }
+    //otherwise index by root context
+    } else {
+        context = QtQml::qmlEngine(object)->rootContext();
+    }
     //at the moment of the attached object creation, the root item is the only one that hasn't a parent
     //only way to avoid creation of this attached for everybody but the root item
-    if (!object->parent() && AppletQuickItemPrivate::s_rootObjects.contains(QtQml::qmlEngine(object))) {
-        return AppletQuickItemPrivate::s_rootObjects.value(QtQml::qmlEngine(object));
+    if (!object->parent() && AppletQuickItemPrivate::s_rootObjects.contains(context)) {
+        return AppletQuickItemPrivate::s_rootObjects.value(context);
     } else {
         return 0;
     }
@@ -418,26 +467,45 @@ Plasma::Applet *AppletQuickItem::applet() const
 
 void AppletQuickItem::init()
 {
-    if (AppletQuickItemPrivate::s_rootObjects.contains(d->qmlObject->engine())) {
+    //FIXME: Plasmoid attached property should be fixed since can't be indexed by engine anymore
+    if (AppletQuickItemPrivate::s_rootObjects.contains(d->qmlObject->rootContext())) {
         return;
     }
 
-    AppletQuickItemPrivate::s_rootObjects[d->qmlObject->engine()] = this;
+    AppletQuickItemPrivate::s_rootObjects[d->qmlObject->rootContext()] = this;
 
     Q_ASSERT(d->applet);
 
     //Initialize the main QML file
     QQmlEngine *engine = d->qmlObject->engine();
 
-    if (d->applet->package().isValid()) {
+    //if the engine of the qmlObject is different from the static one, then we
+    //are using an old version of the api in which every applet had one engine
+    //so initialize a private url interceptor
+    if (d->applet->package().isValid() && !qobject_cast<KDeclarative::QmlObjectSharedEngine *>(d->qmlObject)) {
         PackageUrlInterceptor *interceptor = new PackageUrlInterceptor(engine, d->applet->package());
         interceptor->addAllowedPath(d->coronaPackage.path());
         engine->setUrlInterceptor(interceptor);
     }
 
+    //Force QtQuickControls to use the "Plasma" style for this engine.
+    //this way is possible to mix QtQuickControls and plasma components in applets
+    //while still having the desktop style in configuration dialogs
+    QQmlComponent c(engine);
+    c.setData(QByteArrayLiteral("import QtQuick 2.1\n\
+        import QtQuick.Controls 1.0\n\
+        import QtQuick.Controls.Private 1.0\n \
+        Item {\
+          Component.onCompleted: {\
+            Settings.styleName = \"Plasma\";\
+          }\
+        }"), QUrl());
+    QObject *o = c.create();
+    o->deleteLater();
+
     d->qmlObject->setSource(QUrl::fromLocalFile(d->applet->package().filePath("mainscript")));
 
-    if (!engine || !engine->rootContext() || !engine->rootContext()->isValid() || d->qmlObject->mainComponent()->isError()) {
+    if (!engine || !engine->rootContext() || !engine->rootContext()->isValid() || !d->qmlObject->mainComponent() || d->qmlObject->mainComponent()->isError()) {
         QString reason;
         if (d->applet->package().isValid()) {
             foreach (QQmlError error, d->qmlObject->mainComponent()->errors()) {
@@ -461,15 +529,16 @@ void AppletQuickItem::init()
         d->applet->setLaunchErrorMessage(reason);
     }
 
-    engine->rootContext()->setContextProperty("plasmoid", this);
+    d->qmlObject->rootContext()->setContextProperty(QStringLiteral("plasmoid"), this);
 
     //initialize size, so an useless resize less
     QVariantHash initialProperties;
     //initialize with our size only if valid
     if (width() > 0 && height() > 0) {
-        initialProperties["width"] = width();
-        initialProperties["height"] = height();
+        initialProperties[QStringLiteral("width")] = width();
+        initialProperties[QStringLiteral("height")] = height();
     }
+    d->qmlObject->setInitializationDelayed(false);
     d->qmlObject->completeInitialization(initialProperties);
 
     //otherwise, initialize our size to root object's size
@@ -478,7 +547,6 @@ void AppletQuickItem::init()
         setHeight(d->qmlObject->rootObject()->property("height").value<qreal>());
     }
 
-
     //default fullrepresentation is our root main component, if none specified
     if (!d->fullRepresentation) {
         d->fullRepresentation = d->qmlObject->mainComponent();
@@ -497,10 +565,21 @@ void AppletQuickItem::init()
     //default compactRepresentationExpander is the popup in which fullRepresentation goes
     if (!d->compactRepresentationExpander) {
         d->compactRepresentationExpander = new QQmlComponent(engine, this);
-        d->compactRepresentationExpander->loadUrl(QUrl::fromLocalFile(d->coronaPackage.filePath("compactapplet")));
+        QString compactExpanderPath = d->containmentPackage.filePath("compactapplet");
+
+        if (compactExpanderPath.isEmpty()) {
+            compactExpanderPath = d->coronaPackage.filePath("compactapplet");
+        }
+
+        d->compactRepresentationExpander->loadUrl(QUrl::fromLocalFile(compactExpanderPath));
     }
 
-    d->compactRepresentationCheckTimer.start();
+    //HACK: check the Layout properties we wrote
+    QQmlProperty p(this, "Layout.minimumWidth", QtQml::qmlContext(d->qmlObject->rootObject()));
+
+    d->compactRepresentationCheck();
+    qmlObject()->engine()->rootContext()->setBaseUrl(qmlObject()->source());
+    qmlObject()->engine()->setContextForObject(this, qmlObject()->engine()->rootContext());
 }
 
 
@@ -544,14 +623,14 @@ int AppletQuickItem::switchHeight() const
     return d->switchHeight;
 }
 
-void AppletQuickItem::setSwitchHeight(int width)
+void AppletQuickItem::setSwitchHeight(int height)
 {
-    if (d->switchHeight == width) {
+    if (d->switchHeight == height) {
         return;
     }
 
-    d->switchHeight = width;
-    emit switchHeightChanged(width);
+    d->switchHeight = height;
+    emit switchHeightChanged(height);
 }
 
 QQmlComponent *AppletQuickItem::compactRepresentation()
@@ -611,7 +690,7 @@ void AppletQuickItem::setExpanded(bool expanded)
     }
 
     //if there is no compact representation it means it's always expanded
-    //Containnments are always expanded
+    //Containments are always expanded
     if (d->expanded == expanded) {
         return;
     }
@@ -662,7 +741,7 @@ void AppletQuickItem::geometryChanged(const QRectF &newGeometry, const QRectF &o
     Q_UNUSED(oldGeometry)
 
     QQuickItem::geometryChanged(newGeometry, oldGeometry);
-    d->compactRepresentationCheckTimer.start();
+    d->compactRepresentationCheck();
 }
 
 void AppletQuickItem::itemChange(ItemChange change, const ItemChangeData &value)
